-- NativeSpeech

-- adds "/n" and "/ny" commands that are like "/s" and "/y", but 
-- use the character's native language instead of their faction
-- language

-- it appears that language stuff may not be loaded until variables
-- are loaded.  So, we request to be told when variables are loaded,
-- and detect the player's language then.

-- create a namespace for us to use
NativeSpeech = {}

-- declare the MyLanguage variable
local MyLanguage

function NativeSpeech.OnEvent()
  -- we only have one event we handle, so we can ignore parameters
  
  -- if someone only speaks one language, then their native 
  -- language is language #1. Otherwise, it's #2.
  if (GetNumLanguages() == 1) then
    _, MyLanguage = GetLanguageByIndex(1)
  else
    _, MyLanguage = GetLanguageByIndex(2)
  end
end

-- in order to get an event, we have to have a frame to 
-- register the event to, so create one and register
-- our event handler to it.
local frame = CreateFrame("FRAME", "NativeSpeech_Frame")
frame:RegisterEvent("VARIABLES_LOADED")
frame:SetScript("OnEvent", NativeSpeech.OnEvent)

-- Figure out the character's race. We use the second (language-independent)
-- return from UnitRace()
local MyRace
_, MyRace = UnitRace("player")

-- Function to get information from NativeSpeech. Shouldn't normally be
-- needed, but here just in case for debugging.
function NativeSpeech.GetInfo() 
  print("NativeSpeech detected player race as "..MyRace)
  print("NativeSpeech selected language "..MyLanguage)
end

-- Set up our new commands.
SLASH_NATIVESAY1 = "/n"
SLASH_NATIVEYELL1 = "/ny"

SlashCmdList["NATIVESAY"] = function (args)
    SendChatMessage(args, "SAY", MyLanguage)
end

SlashCmdList["NATIVEYELL"] = function (args)
    SendChatMessage(args, "YELL", MyLanguage)
end

-- if RandomSay is loaded, do this as well
if not RandomSay then return end

SLASH_NATIVESAYRANDOM1 = "/rn"
SLASH_NATIVEYELLRANDOM1 = "/rny"

SlashCmdList["NATIVESAYRANDOM"] = function (args)
    local arg = RandomSay.parse(args)
    if arg then SendChatMessage(arg, "SAY", MyLanguage) end
end

SlashCmdList["NATIVEYELLRANDOM"] = function(args)
    local arg = RandomSay.parse(args)
    if arg then SendChatMessage(arg, "YELL", MyLanguage) end
end
